Package: rexposome
Version: 1.32.0
Title: Exposome exploration and outcome data analysis
Authors@R: c(person("Carles", "Hernandez-Ferrer", , "carles.hernandez@isglobal.org", c("aut", "cre")),
    person("Juan R.", "Gonzalez", ,"juanr.gonzalez@isglobal.org", role = "aut"),
    person("Xavier", "Escribà-Montagut", ,"xavier.escriba@isglobal.org", role = "aut"))
Maintainer: Xavier Escribà Montagut <xavier.escriba@isglobal.org>
Description: Package that allows to explore the exposome and to perform 
    association analyses between exposures and health outcomes.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.2.1
VignetteBuilder: knitr
Depends: R (>= 3.5), Biobase
Imports: methods, utils, stats, lsr, FactoMineR, stringr, circlize,
        corrplot, ggplot2, ggridges, reshape2, pryr, S4Vectors,
        imputeLCMD, scatterplot3d, glmnet, gridExtra, grid, Hmisc,
        gplots, gtools, scales, lme4, grDevices, graphics, ggrepel,
        mice
Suggests: mclust, flexmix, testthat, BiocStyle, knitr, formatR,
        rmarkdown
biocViews: Software, BiologicalQuestion, Infrastructure, DataImport,
        DataRepresentation, BiomedicalInformatics, ExperimentalDesign,
        MultipleComparison, Classification, Clustering
git_url: https://git.bioconductor.org/packages/rexposome
git_branch: RELEASE_3_22
git_last_commit: 4e63989
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 06:02:54 UTC; biocbuild
Author: Carles Hernandez-Ferrer [aut, cre],
  Juan R. Gonzalez [aut],
  Xavier Escribà-Montagut [aut]
