# Generated by roxygen2: do not edit by hand

export(classification)
export(clustering)
export(correlation)
export(expos)
export(exposureNames)
export(extract)
export(exwas)
export(familyNames)
export(get_robust_sd)
export(highAndLow)
export(ilod)
export(imputation)
export(imputeLOD)
export(invExWAS)
export(loadExposome)
export(loadExposome_plain)
export(loadImputed)
export(mexwas)
export(ndim)
export(normalityTest)
export(pca)
export(phenotypeNames)
export(plot3PCA)
export(plotClassification)
export(plotCorrelation)
export(plotEXP)
export(plotEffect)
export(plotExwas)
export(plotFamily)
export(plotHistogram)
export(plotLOD)
export(plotMissings)
export(plotPCA)
export(plotPHE)
export(plotVolcano)
export(readExposome)
export(standardize)
export(tableLOD)
export(tableMissings)
export(tef)
export(toES)
export(trans)
export(volcano_plot)
exportClasses(ExWAS)
exportClasses(ExposomeClust)
exportClasses(ExposomeCorr)
exportClasses(ExposomePCA)
exportClasses(ExposomeSet)
exportClasses(imExposomeSet)
exportClasses(mExWAS)
import(Biobase)
import(utils)
importClassesFrom(Biobase,eSet)
importClassesFrom(S4Vectors,DataFrame)
importFrom(FactoMineR,PCA)
importFrom(Hmisc,impute)
importFrom(circlize,circos.clear)
importFrom(circlize,circos.initialize)
importFrom(circlize,circos.link)
importFrom(circlize,circos.text)
importFrom(circlize,circos.trackPlotRegion)
importFrom(circlize,get.cell.meta.data)
importFrom(corrplot,corrplot)
importFrom(ggplot2,aes)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,coord_polar)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_boxplot)
importFrom(ggplot2,geom_density)
importFrom(ggplot2,geom_errorbar)
importFrom(ggplot2,geom_errorbarh)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_fill_brewer)
importFrom(ggplot2,scale_fill_continuous)
importFrom(ggplot2,scale_fill_discrete)
importFrom(ggplot2,scale_fill_gradient2)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,theme_minimal)
importFrom(ggplot2,xlab)
importFrom(ggplot2,xlim)
importFrom(ggplot2,ylab)
importFrom(ggplot2,ylim)
importFrom(ggrepel,geom_text_repel)
importFrom(glmnet,cv.glmnet)
importFrom(glmnet,glmnet)
importFrom(gplots,heatmap.2)
importFrom(grDevices,rainbow)
importFrom(graphics,layout)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,plot.new)
importFrom(graphics,text)
importFrom(grid,grid.layout)
importFrom(grid,grid.newpage)
importFrom(grid,pushViewport)
importFrom(grid,viewport)
importFrom(gridExtra,grid.arrange)
importFrom(gtools,quantcut)
importFrom(imputeLCMD,impute.MinProb)
importFrom(imputeLCMD,impute.QRILC)
importFrom(lme4,fixef)
importFrom(lsr,cramersV)
importFrom(methods,Summary)
importFrom(methods,formalArgs)
importFrom(methods,new)
importFrom(methods,validObject)
importFrom(pryr,named_dots)
importFrom(reshape2,melt)
importFrom(scales,percent_format)
importFrom(scatterplot3d,scatterplot3d)
importFrom(stats,AIC)
importFrom(stats,IQR)
importFrom(stats,aggregate)
importFrom(stats,anova)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,confint.default)
importFrom(stats,cor)
importFrom(stats,df.residual)
importFrom(stats,fitted)
importFrom(stats,glm)
importFrom(stats,lm)
importFrom(stats,mad)
importFrom(stats,median)
importFrom(stats,predict)
importFrom(stats,pt)
importFrom(stats,qnorm)
importFrom(stats,sd)
importFrom(stats,shapiro.test)
importFrom(stats,update)
importFrom(stats,vcov)
importFrom(stringr,str_pad)
