#' \code{imExposomeSet} for testing purpouses
#'
#'  \code{imExposomeSet} created from the raw data included in the
#'  package. The creation process is ilustrated in the vignette.
#'
#' @usage data("ex_imp")
#' @return An \code{imExposomeSet} object.
#' @examples
#' data("ex_imp")
#' ex_imp
"ex_imp"
