#' \code{ExposomeSet} for testing purpouses
#'
#'  \code{ExposomeSet} with full set of 104 exposures,
#'  1200 simulated samples and 4 phenotypes (asthma status,
#'  BMI measure, sex, and age).
#'
#' @usage data("exposome")
#' @return An \code{ExposomeSet} object.
#' @examples
#' data("exposome")
#' dim(expo)
#' exposureNames(expo)
#' familyNames(expo)
#' sampleNames(expo)
#' phenotypeNames(expo)
"expo"
