#' \code{data.frame} for testing purpouses
#'
#'  \code{data.frame} created with \code{mice} used to test and
#'  ilustrate the creation of \code{imExposomeSet}.
#'
#' @usage data("me")
#' @return A \code{data.frame}.
#' @examples
#' data("me")
#' dim(me)
#' colnames(me)
"me"
